@@ -22,19 +22,26 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_2() {
-	db_install_execute('ALTER TABLE `graph_templates_item`
-		DROP INDEX `local_graph_id`,
-		ADD INDEX `local_graph_id_sequence` (`local_graph_id`, `sequence`)');
+function upgrade_to_1_1_26() {
+	db_install_execute(
+		'ALTER TABLE `host` ADD KEY `status` (`status`);'
+	);
 
-	db_install_execute('ALTER TABLE `graph_tree_items`
-		DROP INDEX `parent`,
-		ADD INDEX `parent_position` (`parent`, `position`)');
-	
-	db_install_execute('ALTER TABLE `graph_template_input_defs`
-		COMMENT = \'Stores the relationship for what graph items are associated\';');
+	db_install_execute(
+		'ALTER TABLE `user_auth_cache` ADD KEY `last_update` (`last_update`);'
+	);
 
-	db_install_execute('ALTER TABLE `graph_tree` ADD INDEX `sequence` (`sequence`)');
+	db_install_execute(
+		'ALTER TABLE `poller_output_realtime` ADD KEY `time` (`time`);'
+	);
 
-	db_install_execute('UPDATE graph_templates_item SET hash="" WHERE local_graph_id>0');
+	db_install_execute(
+		'ALTER TABLE `poller_time` ADD KEY `poller_id_end_time` (`poller_id`, `end_time`);'
+	);
+
+	db_install_execute(
+		'ALTER TABLE `poller_item` 
+		 DROP KEY `rrd_next_step`,
+		 ADD KEY `poller_id_rrd_next_step` (`poller_id`, `rrd_next_step`);'
+	);
 }
